HIFIVE音乐播放器（含海量正版音乐的API）
=======================

## 介绍

&emsp;&emsp;HIFIVE音乐播放器是一款Android、iOS两端的客户端系统，由成都嗨翻屋科技有限公司打造的播放器demo，开源无加密，支持二次开发。
该demo包含了700万+海量正版音乐的API，包含了电台、歌单、搜索歌曲、热歌推荐、歌曲播放、歌词同步等功能。获取音乐API的权限可通过注册HIFIVE音乐开放平台申请授权。

## 图片

<div align=center>
<img src="https://hifive-open-sdk.s3.cn-northwest-1.amazonaws.com.cn/image/sdk/4A843937-F639-4f1d-8A55-0A1734A72FD6.png"/>
</div>

<div align=center>
<img src="https://hifive-open-sdk.s3.cn-northwest-1.amazonaws.com.cn/image/sdk/840036AB-6684-4d95-A663-05C5AD3787B0.png"/>
</div>

<div align=center>
<img src="https://hifive-open-sdk.s3.cn-northwest-1.amazonaws.com.cn/image/sdk/F61F1D78-18C7-486f-80D8-49D2CB26140E.png"/>
</div>

<div align=center>
<img src="https://hifive-open-sdk.s3.cn-northwest-1.amazonaws.com.cn/image/sdk/89DBEC8F-8C1E-446e-85DB-6B6B03C462A9.png"/>
</div>

<div align=center>
<img src="https://hifive-open-sdk.s3.cn-northwest-1.amazonaws.com.cn/image/sdk/74DF12E9-4CCE-45d6-AB17-09918847CF49.png"/>
</div>

## 关联仓库

php端: https://github.com/hifiveai/openmusic-php-sdk

ios端: https://github.com/hifiveai/openmusic-ios-sdk

java端: https://github.com/hifiveai/openmusic-java-sdk

安卓端：https://github.com/hifiveai/openmusic-android-sdk

nodejs端: https://github.com/hifiveai/openmusic-nodejs-sdk

python端: https://github.com/hifiveai/openmusic-python-sdk

## 查看接口文档

[SDK接入文档](/API.md)

[API接入文档](https://open.hifiveai.com/api)

## 申请授权或技术支持

添加微信客服openhifive或者[注册登陆](https://open.hifiveai.com)